searchData={"items":[{"type":"module","title":"IntSet","doc":"Efficiently store and index a set of non-negative integers.\n\nA set can be constructed using `IntSet.new/0`:\n\n    iex> IntSet.new()\n    IntSet.new([])\n\nAn `IntSet` obeys the same set semantics as `MapSet`, and provides\nconstant-time operations for insertion, deletion, and membership checking.\nUse `Enum.member?/2` to check for membership.\n\n    iex> IntSet.new(3) |> Enum.member?(3)\n    true\n\nSets also implement `Collectable`, so it can collect values in any context\nthat a list can:\n\n    iex> Enum.into([1, 2, 3], IntSet.new())\n    IntSet.new([1, 2, 3])\n\nWorking with applications that use bitstrings becomes way easier,\nbecause `IntSet.new/1` accepts a bitstring,\nand `IntSet.bitstring/2` can return one.\n\n    iex> IntSet.new(5) |> IntSet.bitstring()\n    <<0::1, 0::1, 0::1, 0::1, 0::1, 1::1, 0::1, 0::1>>\n\n    iex> IntSet.new(<<0::1, 0::1, 0::1, 0::1, 0::1, 1::1>>)\n    IntSet.new([5])","ref":"IntSet.html"},{"type":"module","title":"Performance - IntSet","doc":"An `IntSet` is significantly faster than Elixir's `MapSet` at set operations (union, intersection, difference, equality),\nbut slower at everything else.\nThe case for memory usage is similar:\nbetter than `MapSet` for set operations,\nworse for everything else.\n\n| Op           | MapSet | IntSet  | Comparison    |\n|--------------|--------|---------|---------------|\n| new          | 4.8K   | 2.46K   | 1.95x slower  |\n| member?      | 6.78M  | 2.93M   | 2.31x slower  |\n| put          | 4.19M  | 1.15M   | 3.66x slower  |\n| union        | 156.4K | 944.31K | 6.04x faster  |\n| difference   | 48.09  | 891.27K | 18.53x faster |\n| intersection | 14.03K | 905.70K | 64.54x faster |\n| equal?       | 0.26M  | 2.41M   | 9.25x faster  |\n\nThere is a benchmark checked into the project repo\nat `perf/performance_test.exs`.\nYou can run it with `mix run` to see some results for yourself.","ref":"IntSet.html#module-performance"},{"type":"module","title":"Serialization - IntSet","doc":"With the use of `IntSet.bitstring/2`, and `IntSet.new/1`,\nyou can serialize this collection very efficiently.\n\n    iex> IntSet.new([4, 8, 15, 16, 23, 42]) |> IntSet.bitstring() |> Base.encode16()\n    \"088181000020\"\n    iex> Base.decode16!(\"088181000020\") |> IntSet.new()\n    IntSet.new([4, 8, 15, 16, 23, 42])","ref":"IntSet.html#module-serialization"},{"type":"function","title":"IntSet.bitstring/1","doc":"Get a bitstring representing the members of a set.","ref":"IntSet.html#bitstring/1"},{"type":"function","title":"Examples - IntSet.bitstring/1","doc":"iex> IntSet.new(0) |> IntSet.bitstring()\n    <<128>>\n\n    iex> IntSet.new(5) |> IntSet.bitstring()\n    <<0::1, 0::1, 0::1, 0::1, 0::1, 1::1, 0::1, 0::1>>\n\n    iex> IntSet.new() |> IntSet.bitstring()\n    <<>>","ref":"IntSet.html#bitstring/1-examples"},{"type":"function","title":"IntSet.delete/2","doc":"Remove a number from the int set.","ref":"IntSet.html#delete/2"},{"type":"function","title":"Examples - IntSet.delete/2","doc":"iex> set = IntSet.new(5)\n    IntSet.new([5])\n    iex> IntSet.delete(set, 5)\n    IntSet.new([])","ref":"IntSet.html#delete/2-examples"},{"type":"function","title":"IntSet.difference/2","doc":"Returns a set that is `int_set1` without the members of `int_set2`.","ref":"IntSet.html#difference/2"},{"type":"function","title":"Examples - IntSet.difference/2","doc":"iex> IntSet.difference(IntSet.new([1, 2]), IntSet.new([2, 3, 4]))\n    IntSet.new([1])","ref":"IntSet.html#difference/2-examples"},{"type":"function","title":"IntSet.disjoint?/2","doc":"Checks if `int_set` and `int_set2` have no members in common.","ref":"IntSet.html#disjoint?/2"},{"type":"function","title":"Examples - IntSet.disjoint?/2","doc":"iex> IntSet.disjoint?(IntSet.new([1, 2]), IntSet.new([3, 4]))\n    true\n\n    iex> IntSet.disjoint?(IntSet.new([1, 2]), IntSet.new([2, 3]))\n    false","ref":"IntSet.html#disjoint?/2-examples"},{"type":"function","title":"IntSet.equal?/2","doc":"Checks if two sets are equal","ref":"IntSet.html#equal?/2"},{"type":"function","title":"Examples - IntSet.equal?/2","doc":"iex> IntSet.equal?(IntSet.new([1, 2]), IntSet.new([2, 1, 1]))\n    true\n    iex> IntSet.equal?(IntSet.new([1, 2]), IntSet.new([3, 4]))\n    false","ref":"IntSet.html#equal?/2-examples"},{"type":"function","title":"IntSet.intersection/2","doc":"Find all elements that are in both `int_set1` and `int_set2`.","ref":"IntSet.html#intersection/2"},{"type":"function","title":"Examples - IntSet.intersection/2","doc":"iex> IntSet.intersection(IntSet.new([1, 2]), IntSet.new([2, 3, 4]))\n    IntSet.new([2])\n\n    iex> IntSet.intersection(IntSet.new([1, 2]), IntSet.new([3, 4]))\n    IntSet.new([])","ref":"IntSet.html#intersection/2-examples"},{"type":"function","title":"IntSet.inverse/2","doc":"Returns a set of size n with all members not in the given IntSet.\n\nYou can visualize this operation as calling `IntSet.difference/2`\nwith the first argument being a full IntSet of size n.","ref":"IntSet.html#inverse/2"},{"type":"function","title":"Examples - IntSet.inverse/2","doc":"iex> IntSet.new(0) |> IntSet.inverse(1)\n    IntSet.new([])\n\n    iex> IntSet.new(0) |> IntSet.inverse(8)\n    IntSet.new([1, 2, 3, 4, 5, 6, 7])\n\n    iex> IntSet.new() |> IntSet.inverse(3)\n    IntSet.new([0, 1, 2])\n\n    iex> IntSet.new() |> IntSet.inverse(9)\n    IntSet.new([0, 1, 2, 3, 4, 5, 6, 7, 8])","ref":"IntSet.html#inverse/2-examples"},{"type":"function","title":"IntSet.new/0","doc":"Create an empty int set.","ref":"IntSet.html#new/0"},{"type":"function","title":"Examples - IntSet.new/0","doc":"iex> IntSet.new\n    IntSet.new([])","ref":"IntSet.html#new/0-examples"},{"type":"function","title":"IntSet.new/1","doc":"Create an int set with some starting value.","ref":"IntSet.html#new/1"},{"type":"function","title":"Examples - IntSet.new/1","doc":"You can create a set with a single starting value.\n\n    iex> IntSet.new(0)\n    IntSet.new([0])\n\nYou can also provide an enumerable of integers to start with.\n\n    iex> IntSet.new([1, 2, 3])\n    IntSet.new([1, 2, 3])\n\nLastly, you can initialize the set with a bit string.\nBinary strings are interpreted as little-endian, with the very first bit\nof the string representing the number zero.\n\n    iex> IntSet.new(<<1 :: 1>>)\n    IntSet.new([0])\n\n    iex> IntSet.new(<<0b1000_1000>>)\n    IntSet.new([0, 4])\n\n    iex> IntSet.new(<<0 :: 1>>)\n    IntSet.new([])","ref":"IntSet.html#new/1-examples"},{"type":"function","title":"IntSet.put/2","doc":"Add a value to the int set.","ref":"IntSet.html#put/2"},{"type":"function","title":"Examples - IntSet.put/2","doc":"iex> set = IntSet.new()\n    IntSet.new([])\n    iex> IntSet.put(set, 0)\n    IntSet.new([0])","ref":"IntSet.html#put/2-examples"},{"type":"function","title":"IntSet.union/2","doc":"Create a new set that contains all of the elements of both x and y.","ref":"IntSet.html#union/2"},{"type":"function","title":"Examples - IntSet.union/2","doc":"iex> a = IntSet.new(7)\n    iex> b = IntSet.new(4)\n    iex> IntSet.union(a, b)\n    IntSet.new([4, 7])","ref":"IntSet.html#union/2-examples"},{"type":"opaque","title":"IntSet.t/0","doc":"","ref":"IntSet.html#t:t/0"},{"type":"extras","title":"IntSet","doc":"<!--\nSPDX-FileCopyrightText: 2024 Rosa Richter\n\nSPDX-License-Identifier: CC-BY-SA-4.0\n-->\n\n# IntSet\n\n[![Hex.pm](https://img.shields.io/hexpm/v/int_set)](https://hex.pm/packages/int_set)\n[![CI](https://github.com/Cantido/int_set/actions/workflows/elixir.yml/badge.svg)](https://github.com/Cantido/int_set/actions/workflows/elixir.yml)\n\nA time- and memory-efficient data structure for positive integers.\n\nFaster than Elixir's MapSet at set operations (union, intersection, difference, equality),\nand slower at everything else.\nAlso can be serlialized wicked small.","ref":"readme.html"},{"type":"extras","title":"Install - IntSet","doc":"This package can be installed by adding `int_set` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:int_set, \"~> 1.5\"}\n  ]\nend\n```\n\nThe docs can be found at [https://hexdocs.pm/int_set](https://hexdocs.pm/int_set).","ref":"readme.html#install"},{"type":"extras","title":"Usage - IntSet","doc":"Usage is pretty much the same as with `MapSet`,\nbut you're only allowed to put positive integers (including zero) into the set.\n\nA set can be constructed using `IntSet.new/0`:\n\n```elixir\niex> IntSet.new()\nIntSet.new([])\n```\n\nAn `IntSet` obeys the same set semantics as `MapSet`, and provides\nconstant-time operations for insertion, deletion, and membership checking.\nUse `Enum.member?/2` to check for membership.\n\n```elixir\niex> IntSet.new(3) |> Enum.member?(3)\ntrue\n```\n\nSets also implement `Collectable`, so it can collect values in any context\nthat a list can:\n\n```elixir\niex> Enum.into([1, 2, 3], IntSet.new())\nIntSet.new([1, 2, 3])\n```\n\nThe `inspect/1` implementation for `IntSet` sorts the members, which makes\nit way easier to write doctests:\n\n```elixir\niex> IntSet.new([3, 1, 2])\nIntSet.new([1, 2, 3])\n```\n\nWorking with applications that use bitstrings becomes way easier,\nbecause `IntSet.new/1` accepts a bitstring,\nand `IntSet.bitstring/2` can return one.\n\n```elixir\niex> IntSet.new(5) |> IntSet.bitstring()\n<<4>>\n\niex> IntSet.new(<<0::1, 0::1, 0::1, 0::1, 0::1, 1::1>>)\nIntSet.new([5])\n```\n\nThis also means that an `IntSet` can be really efficiently serialized with the use of `IntSet.bitstring/2`, and `IntSet.new/1`.\n\n```elixir\niex> IntSet.new([4, 8, 15, 16, 23, 42]) |> IntSet.bitstring() |> Base.encode16()\n\"088181000020\"\niex> Base.decode16!(\"088181000020\") |> IntSet.new()\nIntSet.new([4, 8, 15, 16, 23, 42])\n```","ref":"readme.html#usage"},{"type":"extras","title":"Performance - IntSet","doc":"Check out the iterations-per-second for some operations of `MapSet` compared to `IntSet`.\n\n| Op           | MapSet | IntSet  | Comparison    |\n|--------------|--------|---------|---------------|\n| new          | 4.8K   | 2.46K   | 1.95x slower  |\n| member?      | 6.78M  | 2.93M   | 2.31x slower  |\n| put          | 4.19M  | 1.15M   | 3.66x slower  |\n| union        | 156.4K | 944.31K | 6.04x faster  |\n| difference   | 48.09  | 891.27K | 18.53x faster |\n| intersection | 14.03K | 905.70K | 64.54x faster |\n| equal?       | 0.26M  | 2.41M   | 9.25x faster  |\n\nMemory usage is also better for union, difference, intersection, and equality.\nSee the [`benchmarks/results`] directory for all the benchmarks.\nYou can run the benchmarks for yourself with `mix run benchmarks/benchmark.exs`.","ref":"readme.html#performance"},{"type":"extras","title":"Maintainer - IntSet","doc":"This project was developed by [Rosa Richter](https://github.com/Cantido).\nYou can get in touch with her on [Keybase.io](https://keybase.io/cantido).","ref":"readme.html#maintainer"},{"type":"extras","title":"Contributing - IntSet","doc":"Questions and pull requests are more than welcome.\nI follow Elixir's tenet of bad documentation being a bug,\nso if anything is unclear, please [file an issue](https://github.com/Cantido/int_set/issues/new)!\nIdeally, my answer to your question will be in an update to the docs.\n\nPlease see [CONTRIBUTING.md](CONTRIBUTING.md) for all the details you could ever want about helping me with this project.\n\nNote that this project is released with a Contributor [Code of Conduct].\nBy participating in this project you agree to abide by its terms.","ref":"readme.html#contributing"},{"type":"extras","title":"License - IntSet","doc":"Copyright 2024 Rosa Richter\n\nThis program is free software: you can redistribute it and/or modify\nit under the terms of the GNU Affero General Public License as\npublished by the Free Software Foundation, either version 3 of the\nLicense, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU Affero General Public License for more details.\n\nYou should have received a copy of the GNU Affero General Public License\nalong with this program.  If not, see  .","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"<!--\nSPDX-FileCopyrightText: 2024 Rosa Richter\n\nSPDX-License-Identifier: CC-BY-SA-4.0\n-->\n\n# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n\n## [3.0.0] - 2024-06-08","ref":"changelog.html"},{"type":"extras","title":"Changed - Changelog","doc":"- **BREAKING:** This project will be licensed under the AGPL-3.0-or-later license going forward.\n- Dependency updates\n\n## [2.0.0] - 2023-03-29","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Changelog","doc":"- Inspecting an IntSet now returns a string using `IntString.new([1, 2, 3, ...])` syntax.\n- The internal binary that IntSet uses to store values is now always byte-aligned,\n  and each byte has changed endianness to allow for some internal optimizations.\n- Binaries returned by `IntSet.bitstring/1` is now always byte-aligned.","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Changelog","doc":"- BREAKING: The `byte_align` option for `IntSet.bitstring/1` was removed.\n\n## [1.5.2] - 2022-09-05","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- Copyright headers are now on all files, following the [REUSE Specification](https://reuse.software).","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Fixes for Elixir 1.14 deprecations\n- The project now uses [Earthly](https://earthly.dev) for CI.\n  You can run the entire CI pipeline on your local machine by installing Earthly and running `earthly +all`.\n\n## [1.5.1] - 2021-09-12","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Sponshorship link to `mix.exs`","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- `inspect/2` no longer renders certain sets as charlists.\n\n## [1.5.0] - 2020-10-10","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- `IntSet.bitstring/1` is now `IntSet.bitstring/2` and now accepts an option: `:byte_align`.\n  When this option is set to `true`, the bitstring is padded at the end to make it byte-aligned.\n\n## [1.4.2] - 2019-11-24","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- `IntSet.inverse/2` is now totally fixed.\n\n## [1.4.1] - 2019-11-24","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Some problems with `IntSet.inverse/2` and padding were fixed.\n\n## [1.4.0] - 2019-11-24","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- The `IntSet.inverse/2` function, which is like taking the difference of your IntSet with a completely-full IntSet with n members.\n  Say you have a list of indices, and you want to create a list of all the indices you *don't* have.\n  Just take the inverse, providing a member limit.\n- Added an `.editorconfig` file to the project.\n\n## [1.3.0] - 2018-05-25","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- The `IntSet.equal?/2` function.\n  It does exactly what you think.\n- The `IntSet.intersection/2` function.\n  Returns the elements that are in both sets.\n\n## [1.2.1] - 2018-02-09","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- `IntSet.difference/2` now has a typespec.\n- `IntSet.disjoint?/2` now has docs and a typespec.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- `IntSet.union/2` has been optimized\n\n## [1.2.0] - 2018-02-06","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- The `IntSet.difference/2` function.\n  This function subtracts set B's members from set A.\n- The `IntSet.disjoint?/2` function.\n  Returns `true` if sets A and B have no members in common.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- The `Collectable` implementation was dramatically optimized.\n\n## [1.1.0] - 2018-02-03","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- The `IntSet.bitstring/1` function.\n  Returns a binary with bits flipped at the indices at which the set has members.\n  For example, say you have a set containing 0, 1, and 4.\n  Calling `IntSet.bitstring/1` on that set will return a five-bit-long binary with the first, second, and fifth bits set to 1, and the rest are 0.\n- The library is now typespecced and documented.\n\n## [1.0.0] - 2018-02-01","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Constructor `IntSet.new/0`, which creates a new empty set.\n- Constructor `IntSet.new/1`, which accepts either an enumerable and returns a set containing those elements.\n  This constructor also accepts a bitstring.\n  See the documentation for details on that behavior.\n- The `IntSet.put/2` function.\n  Just like `MapSet.put/2`, this function returns a new set with the given value added.\n- The `IntSet.delete/2` function.\n  Again, just like `MapSet.delete/2`.\n  Returns a new set with the given value removed.\n- The `IntSet.union/2` function.\n  Returns a set that contains elements of both given sets.\n- An implementation of `Inspect` that sorts members before printing them,\n  so the order can be relied upon in doctests.\n- An implementation of `Collectable`.\n- An implementation of `Enumerable`.\n\n[Unreleased]: https://github.com/Cantido/int_set/compare/v3.0.0...HEAD\n[3.0.0]: https://github.com/Cantido/int_set/compare/v2.0.0...v3.0.0\n[2.0.0]: https://github.com/Cantido/int_set/compare/v1.5.2...v2.0.0\n[1.5.2]: https://github.com/Cantido/int_set/compare/v1.5.1...v1.5.2\n[1.5.1]: https://github.com/Cantido/int_set/compare/v1.5.0...v1.5.1\n[1.5.0]: https://github.com/Cantido/int_set/compare/v1.4.2...v1.5.0\n[1.4.2]: https://github.com/Cantido/int_set/compare/v1.4.1...v1.4.2\n[1.4.1]: https://github.com/Cantido/int_set/compare/v1.4.0...v1.4.1\n[1.4.0]: https://github.com/Cantido/int_set/compare/v1.3.0...v1.4.0\n[1.3.0]: https://github.com/Cantido/int_set/compare/v1.3.0...v1.3.0\n[1.2.1]: https://github.com/Cantido/int_set/compare/v1.1.0...v1.2.1\n[1.2.0]: https://github.com/Cantido/int_set/compare/v1.1.0...v1.2.0\n[1.1.0]: https://github.com/Cantido/int_set/compare/v1.0.0...v1.1.0\n[1.0.0]: https://github.com/Cantido/int_set/releases/tag/v1.0.0","ref":"changelog.html#added"},{"type":"extras","title":"Contributor Covenant Code of Conduct","doc":"<!--\nSPDX-FileCopyrightText: 2021 Coraline Ada Ehmke\n\nSPDX-License-Identifier: CC-BY-4.0\n-->\n\n# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Contributor Covenant Code of Conduct","doc":"We as members, contributors, and leaders pledge to make participation in our\ncommunity a harassment-free experience for everyone, regardless of age, body\nsize, visible or invisible disability, ethnicity, sex characteristics, gender\nidentity and expression, level of experience, education, socio-economic status,\nnationality, personal appearance, race, religion, or sexual identity\nand orientation.\n\nWe pledge to act and interact in ways that contribute to an open, welcoming,\ndiverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Contributor Covenant Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the\n  overall community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or\n  advances of any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email\n  address, without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Contributor Covenant Code of Conduct","doc":"Community leaders are responsible for clarifying and enforcing our standards of\nacceptable behavior and will take appropriate and fair corrective action in\nresponse to any behavior that they deem inappropriate, threatening, offensive,\nor harmful.\n\nCommunity leaders have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Contributor Covenant Code of Conduct","doc":"This Code of Conduct applies within all community spaces, and also applies when\nan individual is officially representing the community in public spaces.\nExamples of representing our community include using an official e-mail address,\nposting via an official social media account, or acting as an appointed\nrepresentative at an online or offline event.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Contributor Covenant Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported to the community leaders responsible for enforcement by sending a\nmessage to [Rosa Richter on keybase.io](https://keybase.io/cantido).\nAll complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Enforcement Guidelines - Contributor Covenant Code of Conduct","doc":"Community leaders will follow these Community Impact Guidelines in determining\nthe consequences for any action they deem in violation of this Code of Conduct:","ref":"code_of_conduct.html#enforcement-guidelines"},{"type":"extras","title":"1. Correction - Contributor Covenant Code of Conduct","doc":"**Community Impact**: Use of inappropriate language or other behavior deemed\nunprofessional or unwelcome in the community.\n\n**Consequence**: A private, written warning from community leaders, providing\nclarity around the nature of the violation and an explanation of why the\nbehavior was inappropriate. A public apology may be requested.","ref":"code_of_conduct.html#1-correction"},{"type":"extras","title":"2. Warning - Contributor Covenant Code of Conduct","doc":"**Community Impact**: A violation through a single incident or series\nof actions.\n\n**Consequence**: A warning with consequences for continued behavior. No\ninteraction with the people involved, including unsolicited interaction with\nthose enforcing the Code of Conduct, for a specified period of time. This\nincludes avoiding interactions in community spaces as well as external channels\nlike social media. Violating these terms may lead to a temporary or\npermanent ban.","ref":"code_of_conduct.html#2-warning"},{"type":"extras","title":"3. Temporary Ban - Contributor Covenant Code of Conduct","doc":"**Community Impact**: A serious violation of community standards, including\nsustained inappropriate behavior.\n\n**Consequence**: A temporary ban from any sort of interaction or public\ncommunication with the community for a specified period of time. No public or\nprivate interaction with the people involved, including unsolicited interaction\nwith those enforcing the Code of Conduct, is allowed during this period.\nViolating these terms may lead to a permanent ban.","ref":"code_of_conduct.html#3-temporary-ban"},{"type":"extras","title":"4. Permanent Ban - Contributor Covenant Code of Conduct","doc":"**Community Impact**: Demonstrating a pattern of violation of community\nstandards, including sustained inappropriate behavior,  harassment of an\nindividual, or aggression toward or disparagement of classes of individuals.\n\n**Consequence**: A permanent ban from any sort of public interaction within\nthe community.","ref":"code_of_conduct.html#4-permanent-ban"},{"type":"extras","title":"Attribution - Contributor Covenant Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.0, available at\nhttps://www.contributor-covenant.org/version/2/0/code_of_conduct.html.\n\nCommunity Impact Guidelines were inspired by [Mozilla's code of conduct\nenforcement ladder](https://github.com/mozilla/diversity).\n\n[homepage]: https://www.contributor-covenant.org\n\nFor answers to common questions about this code of conduct, see the FAQ at\nhttps://www.contributor-covenant.org/faq. Translations are available at\nhttps://www.contributor-covenant.org/translations.","ref":"code_of_conduct.html#attribution"},{"type":"extras","title":"Contributing","doc":"<!--\nSPDX-FileCopyrightText: 2024 Rosa Richter\n\nSPDX-License-Identifier: CC-BY-SA-4.0\n-->\n\n# Contributing\n\nThank you for considering contributing!\nI write libraries in my free time and contributions from others help me make great tools.\n\nFollowing these guidelines helps to communicate that you respect my time,\nas the developer managing and developing this open source project.\nIn return, I should reciprocate that respect in addressing your issue,\nassessing changes, and helping you finalize your pull requests.\n\nQuestions and pull requests are more than welcome.\nI follow Elixir's tenet of bad documentation being a bug,\nso if anything is unclear, please [file an issue](https://github.com/Cantido/int_set/issues/new)!\nIdeally, my answer to your question will be in an update to the docs.\n\nPlease note that this project is released with a Contributor [Code of Conduct]. By participating in this project you agree to abide by its terms.\n\n**Working on your first Pull Request?** You can learn how from this *free* series [How to Contribute to an Open Source Project on GitHub](https://egghead.io/series/how-to-contribute-to-an-open-source-project-on-github).","ref":"contributing.html"},{"type":"extras","title":"Ground Rules - Contributing","doc":"- Follow the [Code of Conduct].\n- Keep your commits clear and your pull requests small.\n  This isn't a big library.\n- Run `mix format` on your files before committing them.\n  I like clean diffs.\n- Run `mix credo` and resolve anything of yours that comes up.\n- No dependencies.","ref":"contributing.html#ground-rules"},{"type":"extras","title":"Your First Contribution - Contributing","doc":"- Ask questions!\nI like writing good documentation, and questions make that work more meaningful.\nUse the issue tracker for questions.\nThere's a [questions] tag on the issue tracker for that reason.\n- Tests are always welcome!\n  If you've got some edge case you're worried about, help me test for it!\n- Searching issues or pull requests tagged \"[help wanted]\" or \"[good first issue]\" are great places to get started.","ref":"contributing.html#your-first-contribution"},{"type":"extras","title":"Getting Started - Contributing","doc":"GitHub makes it really easy to submit pull requests. Just:\n\n1. Create your own fork of the code\n2. Do the changes in your fork\n3. [Submit a pull request](https://github.com/Cantido/int_set/compare)\n\nI don't require a CLA or anything like that.","ref":"contributing.html#getting-started"},{"type":"extras","title":"How report a bug - Contributing","doc":"If you find a security vulnerability, do NOT open an issue.\nContact [Rosa on keybase.io](https://keybase.io/cantido) instead!\n\nIn order to determine whether you are dealing with a security issue, ask yourself these two questions:\n\n- Can I access something that's not mine, or something I shouldn't have access to?\n- Can I disable something for other people?\n\nIf the answer to either of those two questions are \"yes\",\nthen you're probably dealing with a security issue.\nNote that even if you answer \"no\" to both questions,\nyou may still be dealing with a security issue, so if you're unsure,\n[message me directly](https://keybase.io/cantido).\n\nPlease [open an issue](https://github.com/Cantido/int_set/issues/new) and\nfollow the directions in the issue template.","ref":"contributing.html#how-report-a-bug"},{"type":"extras","title":"How to suggest a feature or enhancement - Contributing","doc":"The philosopy of this project is to create a small, sharp tool that\ntakes some burden off of the shoulders of developers.\nFeature requests and enhancements should stick to this philosophy.\nHelp me do anything that lets developers do more with their valuable time.\n\nFeature requests give meaning to my work.\n[Open an issue](https://github.com/Cantido/int_set/issues/new) that decribes the feature you'd like to see,\nwhy you need it, and how you'd like it to work.","ref":"contributing.html#how-to-suggest-a-feature-or-enhancement"},{"type":"extras","title":"Code review process - Contributing","doc":"As the primary developer, I will be the one reviewing all pull requests.\nI check GitHub almost every day, so you should be able to hear back from me quickly.\nHowever, I only do this in my free time, so please allow me flexibility.\n\n---\nIf you like this contribution guide, please give a star to [Nadia Eghbal]'s [`contributing-template`] project on GitHub.\nIt was a great help.\n\n[Nadia Eghbal]: https://github.com/nayafia\n[`contributing-template`]: https://github.com/nayafia/contributing-template\n[help wanted]: https://github.com/Cantido/int_set/labels/help%20wanted\n[good first issue]: https://github.com/Cantido/int_set/labels/good%20first%20issue\n[questions]: https://github.com/Cantido/int_set/labels/question\n[Code of Conduct]: code_of_conduct.md","ref":"contributing.html#code-review-process"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}